package minipro

import (
	"encoding/json"
	"fmt"
	"git.168cad.top/go/wechat-client-sdk/core/response"
	"git.168cad.top/go/wechat-client-sdk/httpclient"
)

// NewAccessToken 获取接口调用凭据。
// https://developers.weixin.qq.com/miniprogram/dev/OpenApiDoc/mp-access-token/getAccessToken.html
func (c *MiniClient) NewAccessToken() (*AccessTokenResponse,error) {
	result := &AccessTokenResponse{}
	var url = fmt.Sprintf("https://api.weixin.qq.com/cgi-bin/token?grant_type=client_credential&appid=%s&secret=%s",c.appId, c.secret)
	r,err := httpclient.Get(url)
	if err != nil{
		return nil, err
	}
	e := json.Unmarshal(r, result)
	if err != nil{
		return nil, e
	}
	return result, nil
}

// Code2Session 登录凭证校验。
// https://developers.weixin.qq.com/miniprogram/dev/api-backend/open-api/login/auth.code2Session.html
func (c *MiniClient) Code2Session(code string) (*Code2SessionResponse, error) {
	result := &Code2SessionResponse{}
	var url = fmt.Sprintf("https://api.weixin.qq.com/sns/jscode2session?appid=%s&secret=%s&js_code=%s&grant_type=authorization_code", c.appId, c.secret, code)
	r,err := httpclient.Get(url)
	if err != nil{
		return nil, err
	}
	e := json.Unmarshal(r, result)
	if err != nil{
		return nil, e
	}
	return result, nil
}

type Code2SessionResponse struct {
	OpenID     string `json:"openid"` //用户唯一标识
	SessionKey string `json:"session_key"` //会话密钥
	UnionID    string `json:"unionid"` //用户在开放平台的唯一标识符，若当前小程序已绑定到微信开放平台帐号下会返回，详见 UnionID 机制说明。

	response.MiniProgramResponse
}

type AccessTokenResponse struct {
	AccessToken string `json:"access_token"`//获取到的凭证
	ExpiresIn int32 `json:"expires_in"`//凭证有效时间，单位：秒。目前是7200秒之内的值。
	response.MiniProgramResponse
}